#!/bin/bash
# Build Anleitung https://github.com/CirrusLogic/rpi-linux/wiki/Building-the-code

# Config vom Raspberry sichern auf Raspberry Pi 2 aktuellster Kernel - Prüfen auf bcm2709=y
modprobe configs
zcat /proc/config.gz > Max2PlayConfig
# gesicherte Config für Kernelbuild kopieren nach .config in /linux

####### VORBEREITUNG SYSTEM ############
# Kernel cross compilieren unter Debian Wheezy as root
# Aktuell unter /home/webuser/daten/jessie - Achtung Mountoptionen prüfen mit "mount" muss haben: exec,dev,suid
cd /opt
apt-get update
apt-get install debootstrap --yes
debootstrap jessie jessie
chroot jessie
export LC_ALL=C
echo "deb http://emdebian.org/tools/debian/ jessie main" >> /etc/apt/sources.list.d/crosstools.list
apt-get install curl --yes
curl http://emdebian.org/tools/debian/emdebian-toolchain-archive.key | apt-key add -

dpkg --add-architecture armhf
apt-get update
apt-get install crossbuild-essential-armhf --yes

apt-get install git-core build-essential ncurses-dev bc --yes

####### BUILDVORGANG ###############
##  ACHTUNG CIRRUS LOGIC: http://www.horus.com/~hias/cirrus-driver.html
cd /opt
git clone https://github.com/raspberrypi/linux.git --branch rpi-4.4.y --depth 1
#git clone https://github.com/CirrusLogic/rpi-linux.git --branch rpi-3.18.y --depth 1
#git clone https://github.com/HiassofT/rpi-linux.git --branch cirrus-4.4.y --depth 1

git clone git://github.com/raspberrypi/tools.git --depth 1 
cd rpi-linux
make mrproper

# !!! Raspbi-config in Stammfolder kopieren und eventuell anpassen (z.B. SND_USB_HIFACE, CONFIG_BACKLIGHT_RPI=m aktivieren)
# Filename .config
# ODER: KERNEL=kernel7
# make bcm2709_defconfig für DEFAULT
# https://www.raspberrypi.org/documentation/linux/kernel/configuring.md
# make menuconfig --> setzt config zurück!!!

# Datei Bearbeiten
nano sound/arm/bcm2835-pcm.c
# .formats = SNDRV_PCM_FMTBIT_U8 | SNDRV_PCM_FMTBIT_S16_LE | SNDRV_PCM_FMTBIT_S32_LE, -> nur bei hw_spdif 32 bit setzen
# .rates = SNDRV_PCM_RATE_CONTINUOUS | SNDRV_PCM_RATE_8000_192000,
# .rate_min = 8000,
# .rate_max = 192000,

# Kernelconfig übernehmen und Kernel auf Raspberry 2 / B+ setzen
KERNEL=kernel7
ARCH=arm CROSS_COMPILE=/opt/tools/arm-bcm2708/gcc-linaro-arm-linux-gnueabihf-raspbian-x64/bin/arm-linux-gnueabihf- make oldconfig

# Kernel compilieren -j = Anzahl Prozessoren + 1
ARCH=arm CROSS_COMPILE=/opt/tools/arm-bcm2708/gcc-linaro-arm-linux-gnueabihf-raspbian-x64/bin/arm-linux-gnueabihf- make -j 5

# Module compilieren
mkdir /tmp/modules
ARCH=arm CROSS_COMPILE=/opt/tools/arm-bcm2708/gcc-linaro-arm-linux-gnueabihf-raspbian-x64/bin/arm-linux-gnueabihf- INSTALL_MOD_PATH=/tmp/modules make modules_install

# create Kernel File for EVERY config (raspi 1 und raspi 2)
cd /opt/linux/scripts/
./mkknlimg /opt/linux/arch/arm/boot/zImage kernel7-VERSION.img
./mkknlimg /opt/linux/arch/arm/boot/zImage kernel-VERSION.img

# Optional: Build .deb File for all Contents
# http://ubuntuforums.org/showthread.php?t=910717

# Mehr Infos zur Cirrus Karte unter Jessie: http://www.horus.com/~hias/cirrus-driver.html

# kopieren auf Server
# Packen aller Kernelfiles und Module in tgz files
# cd Kernel3.18.9.v7-192khz
# tar czf Kernel3.18.9.v7-192khz.tgz *
# scp Kernel3.18.9.v7-192khz.tgz root@176.9.62.131:/var/www/shop.max2play.com/magento/media/downloadable/currentversion/wolfsonkernel/Kernel3.18.9.v7-192khz.tgz

scp kernel7.img pi@max2play:/tmp
scp kernel.img pi@max2play:/tmp
cd /tmp/modules
tar czf modules.tgz *
scp modules.tgz pi@max2play:/tmp
#scp ~/code/rpi-linux/arch/arm/boot/dts/rpi-cirrus-wm5102-overlay.dtb pi@<ip-addr>:/tmp

# Installieren auf PI
wget -O /opt/max2play/cache/kernel.tgz shop.max2play.com/media/downloadable/currentversion/wolfsonkernel/Kernel3.18.9.v7-192khz.tgz
tar xzf /opt/max2play/cache/kernel.tgz -C /opt/max2play/cache/
mv /opt/max2play/cache/kernel7.img /boot/
mv /opt/max2play/cache/kernel.img /boot/
tar xzf /opt/max2play/cache/modules.tgz -C /

echo "finished";
